@@ -3,7 +3,7 @@ from pytpp.attributes.top import TopAttributes
 
 
 class ACMEOrderAttributes(TopAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "ACME Order"
     acme_authorization_dn = Attribute('ACME Authorization DN', min_version='17.2')
     acme_expires = Attribute('ACME Expires', min_version='17.2')
     acme_not_after = Attribute('ACME Not After', min_version='17.2')
