@@ -4,4 +4,4 @@ from pytpp.attributes.schedule_base import ScheduleBaseAttributes
 
 
 class AgentDriverAttributes(AgentDriverBaseAttributes, ScheduleBaseAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "Agent Driver"
