@@ -2,7 +2,7 @@ from pytpp.attributes._helper import IterableMeta, Attribute
 
 
 class AgentSSHBaseAttributes(metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "Agent SSH Base"
     credential = Attribute('Credential')
     exclude_remote_mount_points = Attribute('Exclude Remote Mount Points')
     expiration = Attribute('Expiration')
