@@ -3,7 +3,7 @@ from pytpp.attributes.application_base import ApplicationBaseAttributes
 
 
 class ApacheAttributes(ApplicationBaseAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "Apache"
     application_id = Attribute('Application ID', min_version='17.2')
     certificate_chain_file = Attribute('Certificate Chain File')
     certificate_file = Attribute('Certificate File')
