@@ -3,4 +3,4 @@ from pytpp.attributes.flow_action_base import FlowActionBaseAttributes
 
 
 class AssociateKeyExpirationActionAttributes(FlowActionBaseAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "Associate Key Expiration Action"
