@@ -3,4 +3,4 @@ from pytpp.attributes.service_module import ServiceModuleAttributes
 
 
 class AutoLayoutManagerAttributes(ServiceModuleAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "Auto Layout Manager"
