@@ -4,7 +4,7 @@ from pytpp.attributes.driver_base import DriverBaseAttributes
 
 
 class CertificateTrustStoreBaseAttributes(ConnectionBaseAttributes, DriverBaseAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "Certificate Trust Store Base"
     approver = Attribute('Approver')
     automatic_provisioning_disabled = Attribute('Automatic Provisioning Disabled')
     bundle = Attribute('Bundle')
