@@ -3,7 +3,7 @@ from pytpp.attributes.client_work_base import ClientWorkBaseAttributes
 
 
 class ClientAgentConfigurationWorkAttributes(ClientWorkBaseAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "Client Agent Configuration Work"
     agent_cert_trust_bundle = Attribute('Agent Cert Trust Bundle')
     days_of_month = Attribute('Days Of Month')
     days_of_week = Attribute('Days Of Week')
