@@ -3,7 +3,7 @@ from pytpp.attributes.code_signing_environment_template_base import CodeSigningE
 
 
 class CodeSigningCSPEnvironmentTemplateAttributes(CodeSigningEnvironmentTemplateBaseAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "Code Signing CSP Environment Template"
     encryption_key_algorithm = Attribute('Encryption Key Algorithm', min_version='20.2')
     key_container_dn = Attribute('Key Container DN', min_version='20.2')
     key_storage_location = Attribute('Key Storage Location', min_version='20.2')
