@@ -3,7 +3,7 @@ from pytpp.attributes.top import TopAttributes
 
 
 class CodeSigningEnvironmentTemplateBaseAttributes(TopAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "Code Signing Environment Template Base"
     environment_template_update_flow_dn = Attribute('Environment Template Update Flow DN', min_version='21.4')
     flow_instance_macro = Attribute('Flow Instance Macro', min_version='20.1')
     key_use_authentication = Attribute('Key Use Authentication', min_version='20.1')
