@@ -3,7 +3,7 @@ from pytpp.attributes.certificate_authority_base import CertificateAuthorityBase
 
 
 class EntrustSecurityManagerCAAttributes(CertificateAuthorityBaseAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "Entrust Security Manager CA"
     certificate_type = Attribute('Certificate Type', min_version='15.3')
     create_entrust_user = Attribute('Create Entrust User')
     epf_credential = Attribute('EPF Credential')
