@@ -3,5 +3,5 @@ from pytpp.attributes.top import TopAttributes
 
 
 class FlowActionBaseAttributes(TopAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "Flow Action Base"
     rank = Attribute('Rank', min_version='19.2')
