@@ -3,7 +3,7 @@ from pytpp.attributes.http_ca_base import HTTPCABaseAttributes
 
 
 class GeotrustCAAttributes(HTTPCABaseAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "Geotrust CA"
     account_type = Attribute('Account Type')
     address = Attribute('Address')
     billing_contact_first_name = Attribute('Billing Contact First Name')
