@@ -3,7 +3,7 @@ from pytpp.attributes.certificate_trust_store_base import CertificateTrustStoreB
 
 
 class JKSTrustStoreAttributes(CertificateTrustStoreBaseAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "JKS Trust Store"
     key_store = Attribute('Key Store')
     key_store_credential = Attribute('Key Store Credential')
     store_type = Attribute('Store Type')
