@@ -3,7 +3,7 @@ from pytpp.attributes.http_ca_base import HTTPCABaseAttributes
 
 
 class KeynectisSequoiaCAAttributes(HTTPCABaseAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "Keynectis Sequoia CA"
     csr_format_name = Attribute('CSR Format Name')
     csr_name = Attribute('CSR Name')
     customer = Attribute('Customer')
