@@ -3,6 +3,6 @@ from pytpp.attributes.top import TopAttributes
 
 
 class LogChannelAttributes(TopAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "Log Channel"
     configuration = Attribute('Configuration')
     driver_arguments = Attribute('Driver Arguments')
