@@ -3,6 +3,6 @@ from pytpp.attributes.top import TopAttributes
 
 
 class MetadataCategoryAttributes(TopAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "Metadata Category"
     label_text = Attribute('Label Text')
     localization = Attribute('Localization')
