@@ -3,5 +3,5 @@ from pytpp.attributes.metadata_base import MetadataBaseAttributes
 
 
 class MetadataIdentityAttributes(MetadataBaseAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "Metadata Identity"
     single = Attribute('Single')
