@@ -3,7 +3,7 @@ from pytpp.attributes.certificate_authority_base import CertificateAuthorityBase
 
 
 class MicrosoftCAAttributes(CertificateAuthorityBaseAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "Microsoft CA"
     enrollment_agent_certificate = Attribute('Enrollment Agent Certificate')
     given_name = Attribute('Given Name')
     include_cn_as_san = Attribute('Include CN as SAN')
