@@ -3,4 +3,4 @@ from pytpp.attributes.encryption_driver import EncryptionDriverAttributes
 
 
 class NullEncryptionDriverAttributes(EncryptionDriverAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "Null Encryption Driver"
