@@ -3,7 +3,7 @@ from pytpp.attributes.organization import OrganizationAttributes
 
 
 class PolicyAttributes(OrganizationAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "Policy"
     certificate_origin = Attribute('Certificate Origin', min_version='19.1')
     log_view_server = Attribute('Log View Server')
     master_preferences = Attribute('Master Preferences', min_version='17.2')
