@@ -2,7 +2,7 @@ from pytpp.attributes._helper import IterableMeta, Attribute
 
 
 class ProxyBaseAttributes(metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "Proxy Base"
     bypass_proxy_on_local = Attribute('Bypass Proxy on Local')
     proxy_credential = Attribute('Proxy Credential')
     proxy_host = Attribute('Proxy Host')
