@@ -3,7 +3,7 @@ from pytpp.attributes.http_ca_base import HTTPCABaseAttributes
 
 
 class QuoVadisCAAttributes(HTTPCABaseAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "QuoVadis CA"
     api_credentials = Attribute('API Credentials')
     account_name = Attribute('Account Name')
     account_organization = Attribute('Account Organization')
