@@ -3,7 +3,7 @@ from pytpp.attributes.application_base import ApplicationBaseAttributes
 
 
 class TealeafSunimpAttributes(ApplicationBaseAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "TealeafSunimp"
     file_validation_disabled = Attribute('File Validation Disabled', min_version='15.3')
     key_store_credential = Attribute('Key Store Credential')
     key_store_name = Attribute('Key Store Name')
