@@ -3,7 +3,7 @@ from pytpp.attributes.certificate_authority_base import CertificateAuthorityBase
 
 
 class XolphinCAAttributes(CertificateAuthorityBaseAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "Xolphin CA"
     brand = Attribute('Brand')
     included_domains = Attribute('Included Domains')
     product = Attribute('Product')
